summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/knewinvestmentwizard.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/knewinvestmentwizard.h')
-rw-r--r--kmymoney2/dialogs/knewinvestmentwizard.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmymoney2/dialogs/knewinvestmentwizard.h b/kmymoney2/dialogs/knewinvestmentwizard.h
index 8e3be09..43a3be7 100644
--- a/kmymoney2/dialogs/knewinvestmentwizard.h
+++ b/kmymoney2/dialogs/knewinvestmentwizard.h
@@ -68,9 +68,9 @@ public:
* creates all necessary objects for the investment or updates
* them.
*
* @param tqparentId id of tqparent account for the investment
*/
- void createObjects(const TQString& tqparentId);
+ void createObjects(const TQString& parentId);
const MyMoneyAccount& account(void) const { return m_account; }
@@ -68,9 +68,9 @@ public:
* them.
*
- * @param tqparentId id of tqparent account for the investment
+ * @param parentId id of tqparent account for the investment
*/